Modules
- gas_
metering - This module is used to instrument a Wasm module with the gas metering code.
- utils
Functions
- export_
mutable_ globals - Export all declared mutable globals as
prefix_index. - inject_
stack_ limiter - Inject the instumentation that makes stack overflows deterministic, by introducing an upper bound of the stack size.